\thispagestyle{plain}
\begin{center}
    \Large
    \textbf{Realizzazione di una libreria Python su cloud per la fusione e l'analisi dei dati dalla scena del crimine}
        
    \vspace{0.4cm}
    \textbf{Federico Aguzzi}
       
    \vspace{0.9cm}
    \textbf{Abstract}

    Un sistema ben strutturato, costruito su componenti open source esistenti, consente ai non programmatori di modificarlo e migliorarlo, risolvendo problemi pratici e rimanendo facilmente espandibile dagli utenti diretti - un risultato irraggiungibile senza i contributi dell'ingegneria del software.

    Fornendo un'alternativa più semplice, rapida ed efficace alle alternative, sia commerciali che open source - e soprattutto, integrando per la prima volta un approccio \emph{data fusion} in una libreria di analisi - questo progetto mira a fornire uno strumento leggero e comodo per le analisi chemiometriche.
\end{center}
